import React, { useState } from 'react';

const Login = () => {
    const [username, setUsername] = useState('');
    const [password, setPassword] = useState('');
    const [loginStatus, setLoginStatus] = useState('');

    const handleSubmit = async (e) => {
        e.preventDefault();

        try {
            const response = await fetch('http://localhost:8080/Login', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({ username, password })
            });

            if (response.status === 200) {
                const data = await response.json();
                console.log('Login successful. User ID:', data.userId);
                setLoginStatus(`Login successful for user ID: ${data.userId}`);
            } else if (response.status === 401) {
                setLoginStatus('Invalid credentials');
            } else {
                setLoginStatus('Login failed');
            }
        } catch (error) {
            console.error('Error during login:', error);
            setLoginStatus('Server error');
        }
    };

    return (
        <div>
            <form onSubmit={handleSubmit}>
                <div>
                    <label htmlFor="username">Username:</label>
                    <input
                        type="text"
                        id="username"
                        value={username}
                        onChange={(e) => setUsername(e.target.value)}
                    />
                </div>
                <div>
                    <label htmlFor="password">Password:</label>
                    <input
                        type="password"
                        id="password"
                        value={password}
                        onChange={(e) => setPassword(e.target.value)}
                    />
                </div>
                <div>
                    <button type="submit">Log In</button>
                </div>
            </form>
            <p>{loginStatus}</p>
        </div>
    );
};

export default Login;
